@@ -6,18 +6,16 @@ use Carp;
 use UNIVERSAL::require;
 use SQL::Abstract;
 
-use base qw( Data::Page Class::Data::Inheritable ); 
+use base qw( Data::Page Class::Accessor Class::Data::Inheritable );
 
-use vars qw( $VERSION );
-
-$VERSION = '0.565_01';
-
-# D::P inherits from Class::Accessor::Chained::Fast
 __PACKAGE__->mk_accessors( qw( where abstract_attr per_page page order_by _cdbi_app ) );
 
 __PACKAGE__->mk_classdata( '_syntax' );
 __PACKAGE__->mk_classdata( '_pager_class' );
 
+use vars '$VERSION';
+
+$VERSION = 0.52;
 
 =head1 NAME
 
@@ -94,15 +92,14 @@ sub import {
 
     my $caller;
 
-    # find the app - supports subclassing (My::Pager is_a CDBI::P::Pager, not_a CDBI)
+    # find the app
     foreach my $level ( 0 .. 10 )
     {
         $caller = caller( $level );
         last if UNIVERSAL::isa( $caller, 'Class::DBI' )
     }
 
-    warn( "can't find the CDBI app" ), return unless $caller; 
-    #croak( "can't find the CDBI app" ) unless $caller;
+    croak( "can't find the CDBI app" ) unless $caller;
 
     no strict 'refs';
     *{"$caller\::pager"} = \&pager;
@@ -197,14 +194,11 @@ sub _init {
 
     if ( ref( $_[0] ) or $_[0] =~ /^\d+$/ )
     {
-        $where          = shift if ref $_[0]; # SQL::Abstract accepts a hashref or an arrayref 
+        $where          = shift if ref $_[0] eq 'HASH';
         $abstract_attr  = shift if ref $_[0] eq 'HASH';
-#        $order_by       = shift unless $_[0] =~ /^\d+$/;
-#        $per_page       = shift if $_[0] =~ /^\d+$/;
-#        $page           = shift if $_[0] =~ /^\d+$/;
-        $order_by       = shift unless $_[0] and $_[0] =~ /^\d+$/;
-        $per_page       = shift if $_[0] and $_[0] =~ /^\d+$/;
-        $page           = shift if $_[0] and $_[0] =~ /^\d+$/;         
+        $order_by       = shift unless $_[0] =~ /^\d+$/;
+        $per_page       = shift if $_[0] =~ /^\d+$/;
+        $page           = shift if $_[0] =~ /^\d+$/;
         $syntax         = shift;
     }
     else
@@ -255,15 +249,6 @@ sub search_where {
 
     $order_by = [ $order_by ] unless ref $order_by;
     my ( $phrase, @bind ) = $sql->where( $where, $order_by );
-    
-    # If the phrase starts with the ORDER clause (i.e. no WHERE spec), then we are 
-    # emulating a { 1 => 1 } search, but avoiding the bug in Class::DBI::Plugin::AbstractCount 0.04,
-    # so we need to replace the spec - patch from Will Hawes
-    if ( $phrase =~ /^\s*ORDER\s*/i ) 
-    {
-        $phrase = ' 1=1' . $phrase;
-    }
-    
 
     $phrase .= ' ' . $limit_phrase;
     $phrase =~ s/^\s*WHERE\s*//i;
@@ -271,92 +256,27 @@ sub search_where {
     return $cdbi->retrieve_from_sql( $phrase, @bind );
 }
 
-=item retrieve_all
-
-Convenience method, generates a WHERE clause that matches all rows from the table. 
-
-Accepts the same arguments as the C<pager> or C<search_where> methods, except that no 
-WHERE clause should be specified.
-
-Note that the argument parsing routine called by the C<pager> method cannot cope with 
-positional arguments that lack a WHERE clause, so either use named arguments, or the 
-'bit by bit' approach, or pass the arguments directly to C<retrieve_all>.
-
-=cut
-
-sub retrieve_all 
-{
-    my $self = shift;
-
-    my $get_all = {}; # { 1 => 1 };
-
-    unless ( @_ ) 
-    {   # already set pager up via method calls
-            $self->where( $get_all );
-            return $self->search_where;
-    }
-    
-    my @args = ( ref( $_[0] ) or $_[0] =~ /^\d+$/ ) ?
-                ( $get_all, @_ ) :          # send an array
-                ( where => $get_all, @_ );  # send a hash
-
-    return $self->search_where( @args );
-}
-
-sub _setup_pager 
-{
+sub _setup_pager {
     my ( $self ) = @_;
 
-    my $where = $self->where || {}; 
-    
-    # fix { 1 => 1 } as a special case - Class::DBI::Plugin::AbstractCount 0.04 has a bug in 
-    # its column-checking code
-    if ( ref( $where ) eq 'HASH' and $where->{1} )
-    {
-        $where = {};
-        $self->where( {} );
-    }    
-    
-    my $per_page = $self->per_page || croak( 'no. of entries per page not specified' );
-    my $cdbi     = $self->_cdbi_app;
-    my $count    = $cdbi->count_search_where( $where, $self->abstract_attr );
-    my $page     = $self->page || 1;
+    my $where = $self->where || croak( 'must set a query before retrieving results' );
+
+    my $cdbi = $self->_cdbi_app;
+
+    my $count = $cdbi->count_search_where( $where );
+
+    # copy Data::Page->new
+    $self->{TOTAL_ENTRIES}      = $count;
+    $self->{ENTRIES_PER_PAGE}   = $self->per_page || croak( 'no. of entries per page not specified' );
+    $self->{CURRENT_PAGE}       = $self->page || 1;
 
-    $self->total_entries( $count );
-    $self->entries_per_page( $per_page );
-    $self->current_page( $page );
-    
     croak( 'Fewer than one entry per page!' ) if $self->entries_per_page < 1;
 
-    $self->current_page( $self->first_page ) unless defined $self->current_page;
-    $self->current_page( $self->first_page ) if $self->current_page < $self->first_page;
-    $self->current_page( $self->last_page  ) if $self->current_page > $self->last_page;
+    $self->{CURRENT_PAGE} = $self->first_page unless defined $self->current_page;
+    $self->{CURRENT_PAGE} = $self->first_page if $self->current_page < $self->first_page;
+    $self->{CURRENT_PAGE} = $self->last_page  if $self->current_page > $self->last_page;
 }
 
-# SQL::Abstract::_recurse_where eats the WHERE clause 
-#sub where {
-#   my ( $self, $where_ref ) = @_;
-#
-#   return $self->_where unless $where_ref;
-#
-#   my $where_copy;
-#
-#   if ( ref( $where_ref ) eq 'HASH' ) {
-#       $where_copy = { %$where_ref };
-#   }
-#   elsif ( ref( $where_ref ) eq 'ARRAY' )
-#   {
-#       $where_copy = [ @$where_ref ];
-#   }
-#   else
-#   {
-#       die "WHERE clause [$where_ref] must be specified as an ARRAYREF or HASHREF";
-#   }
-#
-#   # this will get eaten, but the caller's value is now protected
-#   $self->_where( $where_copy );
-#}
-
 =item set_syntax( [ $name || $class || $coderef ] )
 
 Changes the syntax used to generate the C<limit> or other phrase that restricts
@@ -434,7 +354,6 @@ Supports the following drivers:
     my %supported = ( pg        => 'LimitOffset',
                       mysql     => 'LimitOffset', # older versions need LimitXY
                       sqlite    => 'LimitOffset', # or LimitYX
-                      sqlite2   => 'LimitOffset', # or LimitYX
                       interbase => 'RowsTo',
                       firebird  => 'RowsTo',
                       );
@@ -461,7 +380,6 @@ sub auto_set_syntax {
     my %supported = ( pg        => 'LimitOffset',
                       mysql     => 'LimitOffset', # older versions need LimitXY
                       sqlite    => 'LimitOffset', # or LimitYX
-                      sqlite2   => 'LimitOffset', # or LimitYX
                       interbase => 'RowsTo',
                       firebird  => 'RowsTo',
                       );
@@ -472,8 +390,6 @@ sub auto_set_syntax {
 
     die __PACKAGE__ . " can't build limit clauses for $not_supported{ $driver }"
         if $not_supported{ $driver };
-        
-    #warn sprintf "Setting syntax to %s for $driver", $supported{ $driver } || 'LimitOffset';
 
     $self->set_syntax( $supported{ $driver } || 'LimitOffset' );
 }
@@ -514,11 +430,11 @@ __END__
 #clause and re-write it this way:
 #
 #SELECT * FROM (
-#   SELECT TOP 5 * FROM (
-#       SELECT TOP 15 my_column
-#       FROM my_table
-#       ORDER BY my_column ASC
-#   ) AS foo ORDER BY my_column DESC
+#	SELECT TOP 5 * FROM (
+#		SELECT TOP 15 my_column
+#		FROM my_table
+#		ORDER BY my_column ASC
+#	) AS foo ORDER BY my_column DESC
 #) AS bar ORDER BY my_column ASC
 #
 #=cut
@@ -611,11 +527,6 @@ the entire results set, before chopping out the requested subset. It's probably
 a good idea to have an index on the column(s) used to order the results. For
 huge tables, this approach to paging may be too inefficient.
 
-=head1 SOURCE CODE
-
-The source code for this module is hosted on GitHub L<https://github.com/majesticcpan/class-dbi-plugin-pager>. 
-Feel free to fork the repository and submit pull requests!
-
 =head1 DEPENDENCIES
 
 L<SQL::Abstract|SQL::Abstract>,
@@ -637,13 +548,12 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Class-DBI-Plugin-Pager>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2012 by David Baird.
-Copyright 2012 Nikolay S. C<majestic@cpan.org>
+Copyright 2004 by David Baird.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-David Baird
+David Baird, C<cpan@riverside-cms.co.uk>
 
